Do not install tempest plugin in train environments

Since train is a python2 env, expand the check in the
devstack plugin to not install the tempest plugin since
it is python3-only.

Change-Id: I67027090a8cc340b85fb1119f0e52bc1f2ffc66d
diff --git a/devstack/plugin.sh b/devstack/plugin.sh
index df0336e..5eac133 100644
--- a/devstack/plugin.sh
+++ b/devstack/plugin.sh
@@ -28,11 +28,11 @@
     case "$2" in
         install)
             # Install dev library if
             # - the release is more recent than stein (devstack in stein would
             #   try to install it in a python2 env, but octavia-tempest-plugin is
             #   now a python3-only project)
             # - or the user explicitly requests it (INSTALL_TEMPEST=True)
-            if [[ "$DEVSTACK_SERIES" != "stein" ]] || [[ "$(trueorfalse False INSTALL_TEMPEST)" == "True" ]]; then
+            if [[ ! "$DEVSTACK_SERIES" =~ (stein|train) ]] || [[ "$(trueorfalse False INSTALL_TEMPEST)" == "True" ]]; then
                 echo_summary "Installing octavia-tempest-plugin"
                 install_octavia_tempest_plugin
             fi
@@ -28,11 +28,11 @@
         install)
             # Install dev library if
-            # - the release is more recent than stein (devstack in stein would
-            #   try to install it in a python2 env, but octavia-tempest-plugin is
-            #   now a python3-only project)
+            # - the release is more recent than train (devstack in train would
+            #   try to install it in a python2 env, but octavia-tempest-plugin
+            #   is now a python3-only project)
             # - or the user explicitly requests it (INSTALL_TEMPEST=True)